@@ -17,8 +17,7 @@ class AuthorizedClipboardUtil:
             xerox.copy(text)
             self.queue.put(text)
         else:
-            print(self.session_key)
-            raise AuthorizedClipboardUtilException(f"Cannot copy text '{text}' to clipboard; auth key '{auth_key}' is invalid ({self.session_key})")
+            raise AuthorizedClipboardUtilException(f"Cannot copy text '{text}' to clipboard; auth key '{auth_key}' is invalid")
 
 
     def paste_text_from_clipboard(self, auth_key):
@@ -28,10 +27,12 @@ class AuthorizedClipboardUtil:
             raise AuthorizedClipboardUtilException(f"Cannot paste text from clipboard; auth key '{auth_key}' is invalid")
 
 
+    def auth_key_matches(self, auth_key):
+        return auth_key == self.session_key
 
 
 def get_auth_marker(server_port, auth_key):
-    return f"witaker:clipboard-server[port={server_port} auth-key='{auth_key}']"
+    return f"witaker:clipboard-server[port={server_port};auth-key='{auth_key}']"
 
 def get_auth_marker_color(server_port, auth_key):
     return get_auth_marker(f"{Fore.CYAN}{server_port}{Fore.RESET}", f"{Fore.GREEN}{auth_key}{Fore.RESET}")
